Module hash
scancode_
rust
0.0.5
Module hash
Module Items
Functions
In scancode_
rust::
utils
scancode_rust
::
utils
Module
hash
Functions

calculate_
md5
Calculate MD5 hash of content and return it as a hex string
calculate_
sha1
Calculate SHA1 hash of content and return it as a hex string
calculate_
sha256
Calculate SHA256 hash of content and return it as a hex string